
# Slot: edge_list_max_rows_number


The maximum number of lines to be loaded from the edges file.

URI: [https://w3id.org/neat/ensmallenRunConfig__edge_list_max_rows_number](https://w3id.org/neat/ensmallenRunConfig__edge_list_max_rows_number)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
